@@ -77,20 +77,20 @@
 #define ADDRESS_BOOK		"addressbook.xml"
 #define ADDRBOOK_DIR		"addrbook"
 #define MANUAL_HTML_INDEX	"claws-mail-manual.html"
-#define HOMEPAGE_URI		"http://www.claws-mail.org/"
-#define MANUAL_URI		"http://www.claws-mail.org/documentation.php"
-#define FAQ_URI			"http://www.claws-mail.org/faq/index.php"
-#define PLUGINS_URI		"http://www.claws-mail.org/plugins.php"
-#define DICTS_URI		"http://www.claws-mail.org/win32/dictionaries.php"
-#define BUGZILLA_URI		"http://www.thewildbeast.co.uk/claws-mail/bugzilla/enter_bug.cgi"
-#define THEMES_URI		"http://www.claws-mail.org/themes.php"
-#define TOOLS_URI		"http://www.claws-mail.org/tools.php"
-#define MAILING_LIST_URI	"http://www.claws-mail.org/MLs.php"
+#define HOMEPAGE_URI		"https://www.claws-mail.org/"
+#define MANUAL_URI		"https://www.claws-mail.org/documentation.php"
+#define FAQ_URI			"https://www.claws-mail.org/faq/index.php"
+#define PLUGINS_URI		"https://www.claws-mail.org/plugins.php"
+#define DICTS_URI		"https://www.claws-mail.org/win32/dictionaries.php"
+#define BUGZILLA_URI		"https://www.thewildbeast.co.uk/claws-mail/bugzilla/enter_bug.cgi"
+#define THEMES_URI		"https://www.claws-mail.org/themes.php"
+#define TOOLS_URI		"https://www.claws-mail.org/tools.php"
+#define MAILING_LIST_URI	"https://www.claws-mail.org/MLs.php"
 #define USERS_ML_ADDR		"users@lists.claws-mail.org"
-#define USERS_ML_URI		"http://lists.claws-mail.org/cgi-bin/mailman/listinfo/users"
-#define GPL_URI			"http://www.gnu.org/licenses/gpl.html"
-#define DONATE_URI		"http://www.claws-mail.org/sponsors.php"
-#define CONFIG_VERSIONS_URI	"http://www.claws-mail.org/cvc.php"
+#define USERS_ML_URI		"https://lists.claws-mail.org/cgi-bin/mailman/listinfo/users"
+#define GPL_URI			"https://www.gnu.org/licenses/gpl.html"
+#define DONATE_URI		"https://www.claws-mail.org/sponsors.php"
+#define CONFIG_VERSIONS_URI	"https://www.claws-mail.org/cvc.php"
 #define RELEASE_NOTES_FILE	"RELEASE_NOTES"
 #define THEMEINFO_FILE		".claws_themeinfo"
 #define FOLDER_LIST		"folderlist.xml"
