@@ -506,8 +506,7 @@ ItemGroup *addressbook_edit_group( AddressBookFile *abf, ItemFolder *parent, Ite
 
 	listEMail = addrbook_get_available_email_list( abf, group );
 	edit_group_load_clist( groupeditdlg.clist_avail, listEMail );
-	mgu_clear_list( listEMail );
-	listEMail = NULL;
+	g_list_free( listEMail );
 	gtk_cmclist_select_row( groupeditdlg.clist_group, 0, 0 );
 	gtk_cmclist_select_row( groupeditdlg.clist_avail, 0, 0 );
 
