@@ -46,6 +46,9 @@
 #include "rssyl_parse_feed.h"
 #include "strutils.h"
 
+gint rssyl_add_msg(Folder *folder, FolderItem *dest, const gchar *file,
+		MsgFlags *flags);
+
 /* rssyl_cb_feed_compare()
  *
  * GCompareFunc function called by glib2's g_slist_find_custom().
@@ -125,6 +128,10 @@ static gint rssyl_cb_feed_compare(const FeedItem *a, const FeedItem *b)
 	if (title_eq && date_eq)
 		return 0;
 
+	/* Or if the url and title match. */
+	if (url_eq && title_eq)
+		return 0;
+
 	/* There is no timestamp and the url matches (or there is none),
 	 * we need to compare titles, ... */
 	if( (no_url || url_eq) && no_date ) {
@@ -307,13 +314,13 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 	/* If one of the timestamps is empty, set it to value of the other one. */
 	if( feed_item_get_date_modified(feed_item) == -1 &&
 			feed_item_get_date_published(feed_item) >= 0 ) {
-		debug_print("RSSyl: setting missing moddate to pubdate %ld\n",
+		debug_print("RSSyl: setting missing moddate to pubdate %"G_GSIZE_FORMAT"\n",
 				feed_item_get_date_published(feed_item));
 		feed_item_set_date_modified(feed_item,
 				feed_item_get_date_published(feed_item));
 	} else if( feed_item_get_date_published(feed_item) == -1 &&
 			feed_item_get_date_modified(feed_item) >= 0 ) {
-		debug_print("RSSyl: setting missing pubdate to modddate %ld\n",
+		debug_print("RSSyl: setting missing pubdate to modddate %"G_GSIZE_FORMAT"\n",
 				feed_item_get_date_modified(feed_item));
 		feed_item_set_date_published(feed_item,
 				feed_item_get_date_modified(feed_item));
@@ -321,7 +328,7 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 			feed_item_get_date_published(feed_item) == -1 &&
 			feed_item_get_sourcedate(feed_item) >= 0 ) {
 		/* If neither item date is set, use date from source (Atom only). */
-		debug_print("RSSyl: setting missing pubdate and moddate to feed source date %ld\n",
+		debug_print("RSSyl: setting missing pubdate and moddate to feed source date %"G_GSIZE_FORMAT"\n",
 				feed_item_get_sourcedate(feed_item));
 		feed_item_set_date_modified(feed_item,
 				feed_item_get_sourcedate(feed_item));
@@ -375,6 +382,7 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 						atoi(pathbasename));
 		g_free(pathbasename);
 		oldperm_flags = msginfo->flags.perm_flags;
+		procmsg_msginfo_free(&msginfo);
 
 		ritem->items = g_slist_remove(ritem->items, old_item);
 		if (g_unlink(ctx->path) != 0) {
@@ -534,7 +542,8 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 			(heading ? heading : ""),
 			(tmpurl ? tmpurl : ""),
 			(tmpurl ? tmpurl : "n/a"),
-			(text ? text : ""), (text ? "\n" : "") );
+			(text ? text : ""),
+			(text && strlen(text) > 0 ? "\n" : "") );
 
 	g_free(meta_charset);
 	g_free(baseurl);
@@ -555,10 +564,15 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 	flags->perm_flags = MSG_NEW | MSG_UNREAD;
 	flags->tmp_flags = 0;
 
-	d = folder_item_add_msg(&ritem->item, template, flags, TRUE);
-	g_free(template);
+	d = rssyl_add_msg(ritem->item.folder, &ritem->item, template, flags);
+
 	g_free(flags);
 
+	if (claws_unlink(template) < 0)
+		FILE_OP_ERROR(template, "unlink");
+
+	g_free(template);
+
 	ctx = g_new0(RFeedCtx, 1);
 	ctx->path = (gpointer)g_strdup_printf("%s%c%d", dirname,
 			G_DIR_SEPARATOR, d);
@@ -571,10 +585,12 @@ void rssyl_add_item(RFolderItem *ritem, FeedItem *feed_item)
 	 * doesn't want to see it unread because of the change. */
 	if (dif != EXISTS_NEW) {
 		if (!(oldperm_flags & MSG_UNREAD) && (ritem->silent_update == 2
-				|| (ritem->silent_update == 1 && dif == EXISTS_CHANGED_TEXTONLY)))
-			procmsg_msginfo_unset_flags(
-					folder_item_get_msginfo((FolderItem *)ritem, d), MSG_NEW | MSG_UNREAD, 0);
+				|| (ritem->silent_update == 1 && dif == EXISTS_CHANGED_TEXTONLY))) {
+			msginfo = folder_item_get_msginfo((FolderItem *)ritem, d);
+			procmsg_msginfo_unset_flags(msginfo, MSG_NEW | MSG_UNREAD, 0);
+			procmsg_msginfo_free(&msginfo);
+		}
 	}
 
-	debug_print("RSSyl: folder_item_add_msg(): %d\n", d);
+	debug_print("RSSyl: rssyl_add_msg(): %d\n", d);
 }
