@@ -691,6 +691,7 @@ gboolean smime_sign(MimeInfo *mimeinfo, PrefsAccount *account, const gchar *from
 	g_hash_table_insert(newinfo->dispositionparameters, g_strdup("filename"),
 			    g_strdup("smime.p7s"));
 	newinfo->data.mem = g_malloc(len + 1);
+	newinfo->tmp = TRUE;
 	g_memmove(newinfo->data.mem, real_content, len);
 	newinfo->data.mem[len] = '\0';
 	newinfo->encoding_type = ENC_BASE64;
@@ -816,7 +817,7 @@ gboolean smime_encrypt(MimeInfo *mimeinfo, const gchar *encrypt_data)
 	g_free(tmpfile);
 
 	/* read temporary file into memory */
-	textstr = fp_read_noconv(fp);
+	textstr = file_read_stream_to_str_no_recode(fp);
 
 	claws_fclose(fp);
 
@@ -869,6 +870,7 @@ gboolean smime_encrypt(MimeInfo *mimeinfo, const gchar *encrypt_data)
 
 	encmultipart->content = MIMECONTENT_FILE;
 	encmultipart->data.filename = tmpfile;
+	encmultipart->tmp = TRUE;
 	procmime_encode_content(encmultipart, ENC_BASE64);
 
 	g_free(enccontent);
