@@ -366,7 +366,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 		if (flowed)
 			FLUSH_LASTLINE();
 	} else if (encoding == ENC_BASE64) {
-		gchar outbuf[BUFFSIZE];
+		gchar outbuf[BUFFSIZE + 1];
 		gint len, inlen, inread;
 		gboolean got_error = FALSE;
 		gboolean uncanonicalize = FALSE;
@@ -390,6 +390,7 @@ gboolean procmime_decode_content(MimeInfo *mimeinfo)
 
 		while ((inlen = MIN(readend - ftell(infp), sizeof(buf))) > 0 && !err) {
 			inread = claws_fread(buf, 1, inlen, infp);
+			memset(outbuf, 0, sizeof(buf));
 			len = g_base64_decode_step(buf, inlen, outbuf, &state, &save);
 			if (uncanonicalize == TRUE && strlen(outbuf) < len && starting) {
 				uncanonicalize = FALSE;
@@ -1270,7 +1271,7 @@ EncodingType procmime_get_encoding_for_text_file(const gchar *file, gboolean *ha
 		octet_percentage = 0.0;
 
 	debug_print("procmime_get_encoding_for_text_file(): "
-		    "8bit chars: %zd / %zd (%f%%)\n", octet_chars, total_len,
+		    "8bit chars: %"G_GSIZE_FORMAT" / %"G_GSIZE_FORMAT" (%f%%)\n", octet_chars, total_len,
 		    100.0 * octet_percentage);
 
 	if (octet_percentage > 0.20 || force_b64) {
@@ -1324,6 +1325,7 @@ static struct TypeTable mime_type_table[] = {
 	{"image", MIMETYPE_IMAGE},
 	{"audio", MIMETYPE_AUDIO},
 	{"video", MIMETYPE_VIDEO},
+	{"model", MIMETYPE_MODEL},
 	{"application", MIMETYPE_APPLICATION},
 	{"message", MIMETYPE_MESSAGE},
 	{"multipart", MIMETYPE_MULTIPART},
@@ -2472,7 +2474,7 @@ static gint procmime_write_message_rfc822(MimeInfo *mimeinfo, FILE *fp)
 			}
 			len = strlen(buf);
 			if (claws_fwrite(buf, sizeof(gchar), len, fp) < len) {
-				g_warning("failed to dump %zd bytes from file", len);
+				g_warning("failed to dump %"G_GSIZE_FORMAT" bytes from file", len);
 				claws_fclose(infp);
 				return -1;
 			}
@@ -2484,7 +2486,7 @@ static gint procmime_write_message_rfc822(MimeInfo *mimeinfo, FILE *fp)
 	case MIMECONTENT_MEM:
 		len = strlen(mimeinfo->data.mem);
 		if (claws_fwrite(mimeinfo->data.mem, sizeof(gchar), len, fp) < len) {
-			g_warning("failed to dump %zd bytes from mem", len);
+			g_warning("failed to dump %"G_GSIZE_FORMAT" bytes from mem", len);
 			return -1;
 		}
 		break;
@@ -2536,7 +2538,7 @@ static gint procmime_write_multipart(MimeInfo *mimeinfo, FILE *fp)
 				break;
 			len = strlen(buf);
 			if (claws_fwrite(buf, sizeof(gchar), len, fp) < len) {
-				g_warning("failed to write %zd", len);
+				g_warning("failed to write %"G_GSIZE_FORMAT, len);
 				claws_fclose(infp);
 				return -1;
 			}
@@ -2551,7 +2553,7 @@ static gint procmime_write_multipart(MimeInfo *mimeinfo, FILE *fp)
 			*(str2 - 2) = '\0';
 		len = strlen(str);
 		if (claws_fwrite(str, sizeof(gchar), len, fp) < len) {
-			g_warning("failed to write %zd from mem", len);
+			g_warning("failed to write %"G_GSIZE_FORMAT" from mem", len);
 			g_free(str);
 			return -1;
 		}
@@ -2662,3 +2664,104 @@ gchar *procmime_get_part_file_name(MimeInfo *mimeinfo)
 	return base;
 }
 
+void *procmime_get_part_as_string(MimeInfo *mimeinfo,
+		gboolean null_terminate)
+{
+	FILE *infp;
+	gchar *data;
+	gint length, readlength;
+
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+
+	if (mimeinfo->encoding_type != ENC_BINARY &&
+			!procmime_decode_content(mimeinfo))
+		return NULL;
+
+	if (mimeinfo->content == MIMECONTENT_MEM)
+		return g_strdup(mimeinfo->data.mem);
+
+	if ((infp = claws_fopen(mimeinfo->data.filename, "rb")) == NULL) {
+		FILE_OP_ERROR(mimeinfo->data.filename, "claws_fopen");
+		return NULL;
+	}
+
+	if (fseek(infp, mimeinfo->offset, SEEK_SET) < 0) {
+		FILE_OP_ERROR(mimeinfo->data.filename, "fseek");
+		claws_fclose(infp);
+		return NULL;
+	}
+
+	length = mimeinfo->length;
+
+	data = g_malloc(null_terminate ? length + 1 : length);
+	if (data == NULL) {
+		g_warning("Could not allocate %d bytes for procmime_get_part_as_string.\n",
+				(null_terminate ? length + 1 : length));
+		claws_fclose(infp);
+		return NULL;
+	}
+
+	readlength = claws_fread(data, length, 1, infp);
+	if (readlength <= 0) {
+		FILE_OP_ERROR(mimeinfo->data.filename, "fread");
+		g_free(data);
+		claws_fclose(infp);
+		return NULL;
+	}
+
+	claws_fclose(infp);
+
+	if (null_terminate)
+		data[length] = '\0';
+
+	return data;
+}
+
+/* Returns an open GInputStream. The caller should just
+ * read mimeinfo->length bytes from it and then release it. */
+GInputStream *procmime_get_part_as_inputstream(MimeInfo *mimeinfo)
+{
+	cm_return_val_if_fail(mimeinfo != NULL, NULL);
+
+	if (mimeinfo->encoding_type != ENC_BINARY &&
+			!procmime_decode_content(mimeinfo)) {
+		g_warning("could not decode part");
+		return NULL;
+	}
+	if (mimeinfo->content == MIMECONTENT_MEM) {
+		/* NULL for destroy func, since we're not copying
+		 * the data for the stream. */
+		return g_memory_input_stream_new_from_data(
+				mimeinfo->data.mem,
+				mimeinfo->length, NULL);
+	} else {
+		return g_memory_input_stream_new_from_data(
+				procmime_get_part_as_string(mimeinfo, FALSE),
+				mimeinfo->length, g_free);
+	}
+}
+
+GdkPixbuf *procmime_get_part_as_pixbuf(MimeInfo *mimeinfo, GError **error)
+{
+	GdkPixbuf *pixbuf;
+	GInputStream *stream;
+
+	if (error)
+		*error = NULL;
+
+	stream = procmime_get_part_as_inputstream(mimeinfo);
+	if (stream == NULL) {
+		if (error)
+			*error = g_error_new_literal(G_FILE_ERROR, -1, _("Could not decode part"));
+		return NULL;
+	}
+
+	pixbuf = gdk_pixbuf_new_from_stream(stream, NULL, error);
+	g_object_unref(stream);
+
+	if (error && *error != NULL)
+		return NULL;
+
+	return pixbuf;
+}
+
