@@ -1,6 +1,6 @@
 /*
- * Sylpheed -- a GTK+ based, lightweight, and fast e-mail client
- * Copyright (C) 1999-2012 Hiroyuki Yamamoto and the Claws Mail team
+ * Claws Mail -- a GTK+ based, lightweight, and fast e-mail client
+ * Copyright (C) 1999-2016 Hiroyuki Yamamoto and the Claws Mail team
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -14,7 +14,6 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
- * 
  */
 
 /* code ported from gedit */
@@ -271,7 +270,7 @@ static gint undo_merge(GList *list, guint start_pos, guint end_pos,
 			last_undo->text = temp_string;
 		}
 	} else
-		debug_print("Unknown action [%i] inside undo merge encountered", action);
+		debug_print("Unknown action [%i] inside undo merge encountered\n", action);
 
 	return TRUE;
 }
